window {
  background-color: #CCCCCC;
}

box.tabpanel {
  border: 1px outset #CCCCCC;
  padding: 10px;
}

tab {
  padding-left: 10px;
  padding-right: 10px;
}

treehead > treerow > treecell {
  border: 1px outset #CCCCCC;
  padding-top: 1px;
  padding-bottom: 1px;
  padding-left: 5px;
  padding-right: 5px;
  background-color: #CCCCCC;
  color: #000000;
}

treechildren > treeitem > treerow > treecell {
  border-right: 1px solid #CCCCCC;
  border-bottom: 1px solid #CCCCCC;
  color: inherit;
  padding-left: 10px;
  padding-top: 1px;
  padding-bottom: 1px;
}

treechildren > treeitem > treerow > treecell.fieldcell {
  border-right: 1px solid #CCCCCC;
  border-bottom: 1px solid #CCCCCC;
  color: inherit;
  padding: 0px;
  margin: 0px;
}


treechildren > treeitem > treerow [selectedrow ~= false] {
  background-color: white;
  color: black;
}

treechildren > treeitem > treerow [selectedrow ~= true] {
  background-color: #336699;
  color: white;
}

tree#infotree treechildren > treeitem > treerow [selectedrow ~= false] {
  background-color: white;
  color: black;
}

tree#infotree treechildren > treeitem > treerow [selectedrow ~= true] {
  background-color: white;
  color: black;
}

tree {
  border: 1px inset #CCCCCC;
}

a {
  color: #0000FF;
  text-decoration: underline;
}

a:hover {
  color: #FF0000;
  text-decoration: underline;
}

tree treechildren > treeitem > treerow[selectedrow=true] > treecell > a:link {
  color: #FFFFFF;
}

tree treechildren > treeitem > treerow[selectedrow ~= true]  > treecell > a:hover {
  color: #FFFFFF;
}

input.dispcell {
  border: none;
  background-color: #CCCCCC;
  height: 12px;
  font-family: tahoma;
  font-size: 10px;
}
