 /** this should only contain XUL dialog and document window widget defaults. Defaults for widgets of
    a particular application should be in that application's style sheet.
	For example style definitions for navigator can be found in navigator.css

   THIS FILE IS LOCKED DOWN.  YOU ARE NOT ALLOWED TO MODIFY IT WITHOUT FIRST HAVING YOUR
   CHANGES REVIEWED BY hyatt@netscape.com.
**/

@import url(chrome://global/skin/scrollbars.css);

@namespace url(http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul); /* set default namespace to XUL */
@namespace html url("http://www.w3.org/TR/REC-html40"); /* namespace for HTML elements */

* {
  display: block;
}

*[collapsed="true"] {
  visibility: collapsed;
}

*[hidden="true"] {
  display: none;
}

/* Focus rules for XUL widgets */
checkbox,radio,tree,menulist {
  user-focus: normal;
}

menupopup, splitter {
  user-focus: ignore;
}

treechildren, treehead, treefoot {
  user-focus: none;
}

/** 
 * All elements that have no visual representation
 */
commands, commandset, command {
	display: none;
}

broadcasterset, broadcaster {
	display: none;
}

observes {
	display: none;
}

template {
	display: none;
}

/**********************************
 * Window
 **********************************/

window { 
  overflow: hidden;
}

/**********************************
 * XUL widgets
 **********************************/

/******** Browser, editor, iframe ********/

browser, editor, iframe {
  display: inline;
}

/******** Box *******/


/******* ToolBox & ToolBar *******/

toolbox { 
  user-focus: ignore;
  behavior: url(resource:/chrome/xulBindings.xml#toolbox);
}

toolbar, menubar {
  user-focus: ignore;
}

toolbar,menubar {
  behavior: url(resource:/chrome/xulBindings.xml#toolbar);
}

toolbargrippy {
  behavior: url(resource:/chrome/xulBindings.xml#toolbargrippy);
}

toolbar[collapsed="true"] {
  visibility: visible;
}

box.toolbar-holder[collapsed="true"] {
  visibility: collapse;
}

/****** Progress Meter ********/

/****** TitledBox ******/

/********* XP Menus ***********/


menubar > menu {
  behavior: url("resource:/chrome/xulBindings.xml#menusOnMenuBar");
}

menu,menuitem {
  behavior: url("resource:/chrome/xulBindings.xml#menus");
}

menupopup {
  /*behavior: url("resource:/chrome/xulBindings.xml#popups");*/
  display: none;
}

popup {
  /*behavior: url("resource:/chrome/xulBindings.xml#popups");*/
  display: none;
}

menupopup[menugenerated="true"] {
  display: block;
}

popup[menugenerated="true"] {
  display: block;
}

menupopup, popup {
  visibility: hidden;
  z-index: 2147483647; 
}

menupopup[menuactive="true"] {
  visibility: visible;
}

popup[menuactive="true"] {
  visibility: visible;
}

menulist {
  behavior: url("resource:/chrome/xulBindings.xml#menulist");
}

menulist[editable="true"] {
  behavior: url("resource:/chrome/xulBindings.xml#menulist-editable");
}

menubutton {
  behavior: url("resource:/chrome/xulBindings.xml#menubutton");
}

/******** Titled buttons **********/

/******** Tree widget **********/

tree {
 display: table;
 table-layout: fixed;
 width: 200px;
 height: 200px;
 min-width: 0px;
 min-height: 0px;
}

treeitem { 
 display: table-row-group; 
} 

treerow {
 display: table-row;
}

treehead { 
 display: table-header-group; 
} 

treechildren { 
 display: table-row-group;
} 

treecell { 
 display: table-cell;
 behavior: url("resource:/chrome/xulBindings.xml#treecell");
} 

treecell[indent="true"] {
 behavior: url("resource:/chrome/xulBindings.xml#treecell-indented-leaf");
}

treeitem[container="true"] > treerow > treecell[indent="true"] {
 behavior: url("resource:/chrome/xulBindings.xml#treecell-indented-folder");
}

treeitem > treechildren {
  display: none;
}

treeitem[open="true"] > treechildren {
  display: table-row-group;
}

treecol {
 display: table-column;
}

treecolgroup {
  display: table-column-group;
}

treehead > treerow > treecell {
  behavior: url("resource:/chrome/xulBindings.xml#treecell-header");
}

/********** Tab widget *********/

tab {
  behavior: url(resource:/chrome/xulBindings.xml#tab);
}

:-moz-deck-hidden {
   visibility: hidden;
}

/********** checkbox **********/

checkbox {
  behavior: url(resource:/chrome/xulBindings.xml#checkbox);
}

checkbox.iconic {
  behavior: url(resource:/chrome/xulBindings.xml#checkbox-iconic);
}

radio {
  behavior: url(resource:/chrome/xulBindings.xml#radio);
}

radio.iconic {
  behavior: url(resource:/chrome/xulBindings.xml#radio-iconic);
}

radiogroup {
  behavior: url(resource:/chrome/xulBindings.xml#radiogroup);
}

button, button.left {
  behavior: url(resource:/chrome/xulBindings.xml#buttonleft);
}

button.right {
  behavior: url(resource:/chrome/xulBindings.xml#buttonright);
}

separator {
  behavior: url(resource:/chrome/xulBindings.xml#separator);
}

/* appending to end so we don't make hyatt cry */
progressmeter {
  behavior: url(resource:/chrome/xulBindings.xml#progressmeter);
}

textfield {
  behavior: url(resource:/chrome/xulBindings.xml#textfield);
}

textfield[multiline="true"] {
  behavior: url(resource:/chrome/xulBindings.xml#textarea);
}

text {
  behavior: url(resource:/chrome/xulBindings.xml#text);
}

text[editable="true"], text[editable="true"][mode="display"] {
  behavior: url(resource:/chrome/xulBindings.xml#text-editable-display);
}

text[editable="true"][mode="edit"] {
  behavior: url(resource:/chrome/xulBindings.xml#text-editable-edit);
}

colorpicker {
  behavior: url(resource:/chrome/xulBindings.xml#colorpicker);
}
