titledbutton#mini-nav {
	list-style-image:url("chrome://global/skin/taskbar-navigator.gif");
}

titledbutton#mini-mail {
	list-style-image:url("chrome://global/skin/taskbar-mail.gif");
}

titledbutton#mini-addr {
	list-style-image:url("chrome://global/skin/taskbar-addressbook.gif");
}

titledbutton#mini-comp {
	list-style-image:url("chrome://global/skin/taskbar-composer.gif");
}


toolbar#taskbar {
	color: white;
	background-color: #003366;
	padding: 0px;
	border: none;
	margin: 0px;
	margin-top: 2px;
	min-height: 1em;
	user-focus: ignore;
}

titledbutton.taskbutton {
	margin-right: 1em !important;
	padding-left: 3px !important;
}

titledbutton.taskbutton:hover {
	padding-left: 3px !important;
}

titledbutton.taskbutton:active {
  padding: 2px 0px 0px 4px !important;
}

spring.taskbarspacer {
   min-width: 0.3em;
   width: 1em;
}
