@import url(chrome://global/skin/);

treecell.directory > .tree-button {
  list-style-image: url("chrome://global/skin/dir-closed.gif");
}

treecell.directory[open="true"] > .tree-button {
  list-style-image: url("chrome://global/skin/dir-open.gif");
}

treecell.file > .tree-button {
  list-style-image: url("chrome://global/skin/blank.gif");
}
/*
treeitem.hidden > treerow > treecell > .tree-button {
  color: #CCCCCC;
}

treeitem.hidden > treerow > treecell > .tree-icon {
  list-style-image: url("chrome://global/skin/blank.gif");
}
*/
