titledbutton#security-button {
	list-style-image:url("chrome://navigator/skin/unlock.gif");
}

titledbutton#security-button[level="high"] {
    list-style-image:url("chrome://navigator/skin/lock.gif");        
}

titledbutton#security-button[level="low"] {
    list-style-image:url("chrome://navigator/skin/lock.gif");        
}

titledbutton#security-button[level="broken"] {
    list-style-image:url("chrome://navigator/skin/broken.gif");        
}